@@ -40,28 +40,30 @@ let option_element_of_option =
   | Some v -> Some (new Gdome.element v)
 
 class math_view_skel obj = object
- inherit GContainer.container (obj : Gtk_mathview.math_view obj)
+ inherit GObj.widget (obj : Gtk_mathview.math_view obj)
  method freeze = MathView.freeze obj
  method thaw = MathView.thaw obj
  method load_uri ~filename =
   if not (MathView.load_uri obj ~filename) then raise (ErrorLoadingFile filename)
- method load_doc ~dom =
-  if not (MathView.load_doc obj ~dom:((dom : Gdome.document)#as_Document)) then
+ method load_root ~root =
+  if not (MathView.load_root obj ~root:((root : Gdome.element)#as_Element)) then
    raise ErrorLoadingDOM
  method unload = MathView.unload obj
  method select element = MathView.select obj ((element : Gdome.element)#as_Element)
  method unselect element = MathView.unselect obj ((element : Gdome.element)#as_Element)
  method is_selected element = MathView.is_selected obj ((element : Gdome.element)#as_Element)
  method get_element_at x y = option_element_of_option (MathView.get_element_at obj x y)
- method get_width = MathView.get_width obj
- method get_height = MathView.get_height obj
+ method structure_changed element = MathView.structure_changed obj ((element : Gdome.element)#as_Element)
+ method attribute_changed element ~name = MathView.attribute_changed obj ((element : Gdome.element)#as_Element) ((name : Gdome.domString)#as_DOMString)
+ method get_bounding_box = MathView.get_bounding_box obj
+ method get_size = MathView.get_size obj
  method get_top = MathView.get_top obj
  method set_top x y  = MathView.set_top obj x y
  method set_adjustments adj1 adj2 = MathView.set_adjustments obj (GData.as_adjustment adj1) (GData.as_adjustment adj2)
- method get_hadjustment = new GData.adjustment (MathView.get_hadjustment obj)
- method get_vadjustment = new GData.adjustment (MathView.get_vadjustment obj)
+ method get_adjustments =
+   let hadj, vadj = MathView.get_adjustments obj in
+   new GData.adjustment hadj, new GData.adjustment vadj
  method get_buffer = MathView.get_buffer obj
- method get_drawing_area = new GMisc.drawing_area (MathView.get_drawing_area obj)
  method set_font_size = MathView.set_font_size obj
  method get_font_size = MathView.get_font_size obj
  method set_log_verbosity = MathView.set_log_verbosity obj
@@ -69,8 +71,8 @@ class math_view_skel obj = object
 end
 
 class math_view_signals obj = object
-  inherit GContainer.container_signals_impl obj
-  inherit math_view_sigs
+  inherit GObj.widget_signals_impl obj
+  inherit math_view__g_meta_dom_sigs
 end
 
 class math_view obj = object
@@ -79,7 +81,7 @@ class math_view obj = object
 end
 
 let math_view ?hadjustment ?vadjustment ?font_size ?log_verbosity =
-  GtkBase.Container.make_params ~cont:(
+  GtkBase.Widget.size_params ~cont:(
   OgtkMathViewProps.pack_return
     (fun p -> OgtkMathViewProps.set_params (new math_view (MathView.create p)) ~font_size ~log_verbosity)) []
 ;;
