@@ -26,21 +26,21 @@ exception ErrorWritingFile of string
 exception ErrorLoadingDOM
 
 class math_view_signals :
-  ([> `container | `gtk | `mathview | `widget] as 'b) Gtk.obj ->
+  ([> `gtk | `mathview_gmetadom | `widget] as 'b) Gtk.obj ->
   object ('a)
-    inherit GContainer.container_signals
+    inherit GObj.widget_signals
     val after: bool
     val obj: 'b Gtk.obj
     method click :
-      callback:(Gdome.element option -> int -> unit) -> GtkSignal.id
+      callback:(Gdome.element option * int * int * int -> unit) -> GtkSignal.id
     method element_over :
-      callback:(Gdome.element option -> int -> unit) -> GtkSignal.id
+      callback:(Gdome.element option * int * int * int -> unit) -> GtkSignal.id
     method select_begin :
-      callback:(Gdome.element option -> int -> unit) -> GtkSignal.id
+      callback:(Gdome.element option * int * int * int -> unit) -> GtkSignal.id
     method select_over :
-      callback:(Gdome.element option -> int -> unit) -> GtkSignal.id
+      callback:(Gdome.element option * int * int * int -> unit) -> GtkSignal.id
     method select_end :
-      callback:(Gdome.element option -> int -> unit) -> GtkSignal.id
+      callback:(Gdome.element option * int * int * int -> unit) -> GtkSignal.id
     method select_abort :
       callback:(unit -> unit) -> GtkSignal.id
   end
@@ -48,23 +48,23 @@ class math_view_signals :
 class math_view_skel :
   (Gtk_mathview.math_view Gtk.obj as 'a)->
   object
-    inherit GContainer.container
+    inherit GObj.widget
     method freeze : unit
     method thaw : unit
     method get_buffer : Gdk.pixmap
     method get_font_size : int
-    method get_drawing_area : GMisc.drawing_area
-    method get_hadjustment : GData.adjustment
-    method get_height : int
+    method get_adjustments : GData.adjustment * GData.adjustment
+    method get_size : int * int
     method get_log_verbosity : int
     method get_top : int * int
-    method get_vadjustment : GData.adjustment
-    method get_width : int
     method load_uri : filename:string -> unit
-    method load_doc : dom:Gdome.document -> unit
+    method load_root : root:Gdome.element -> unit
     method set_adjustments : GData.adjustment -> GData.adjustment -> unit
     method set_font_size : int -> unit
     method set_log_verbosity : int -> unit
+    method structure_changed : Gdome.element -> unit
+    method attribute_changed : Gdome.element -> name:Gdome.domString -> unit
+    method get_bounding_box : int * int * int
     method select : Gdome.element -> unit
     method unselect : Gdome.element -> unit
     method get_element_at : int -> int -> Gdome.element option
@@ -86,7 +86,6 @@ val math_view :
   ?vadjustment:GData.adjustment ->
   ?font_size:int ->
   ?log_verbosity:int ->
-  ?border_width:int ->
   ?width:int ->
   ?height:int ->
   ?packing:(GObj.widget -> unit) -> ?show:bool -> unit -> math_view
