@@ -33,54 +33,58 @@ external _gtkmathview_init : unit -> unit = "ml_gtk_mathview_init"
 let () = _gtkmathview_init ()
 
 module MathView = struct
-  include MathView
-  external freeze : [>`mathview] obj -> unit =
+  include MathView_GMetaDOM
+  external freeze : [>`mathview_gmetadom] obj -> unit =
    "ml_gtk_math_view_freeze"
-  external thaw : [>`mathview] obj -> unit =
+  external thaw : [>`mathview_gmetadom] obj -> unit =
    "ml_gtk_math_view_thaw"
-  external load_uri : [>`mathview] obj -> filename:string -> bool =
+  external load_uri : [>`mathview_gmetadom] obj -> filename:string -> bool =
    "ml_gtk_math_view_load_uri"
-  external load_doc : [>`mathview] obj -> dom:[> `Document] GdomeT.t -> bool =
-   "ml_gtk_math_view_load_doc"
-  external unload : [>`mathview] obj -> unit =
+  external load_root : [>`mathview_gmetadom] obj -> root:[> `Element] GdomeT.t -> bool =
+   "ml_gtk_math_view_load_root"
+  external unload : [>`mathview_gmetadom] obj -> unit =
    "ml_gtk_math_view_unload"
   external select :
-   [>`mathview] obj -> [> `Element] GdomeT.t -> unit =
+   [>`mathview_gmetadom] obj -> [> `Element] GdomeT.t -> unit =
    "ml_gtk_math_view_select"
   external unselect :
-   [>`mathview] obj -> [> `Element] GdomeT.t -> unit =
+   [>`mathview_gmetadom] obj -> [> `Element] GdomeT.t -> unit =
    "ml_gtk_math_view_unselect"
   external is_selected :
-   [>`mathview] obj -> [> `Element] GdomeT.t -> bool =
+   [>`mathview_gmetadom] obj -> [> `Element] GdomeT.t -> bool =
    "ml_gtk_math_view_is_selected"
+  external structure_changed :
+   [>`mathview_gmetadom] obj -> [> `Element] GdomeT.t -> unit =
+   "ml_gtk_math_view_structure_changed"
+  external attribute_changed :
+   [>`mathview_gmetadom] obj -> [> `Element] GdomeT.t -> name:TDOMString.t -> unit =
+   "ml_gtk_math_view_attribute_changed"
+  external get_bounding_box :
+   [>`mathview_gmetadom] obj -> (int * int * int) =
+   "ml_gtk_math_view_get_bounding_box"
   external get_element_at :
-   [> `mathview] obj -> int -> int -> TElement.t option =
+   [> `mathview_gmetadom] obj -> int -> int -> TElement.t option =
    "ml_gtk_math_view_get_element_at"
    (* beginning of prop-like methods *)
-  external get_width : [>`mathview] obj -> int =
-   "ml_gtk_math_view_get_width"
-  external get_height : [>`mathview] obj -> int =
-   "ml_gtk_math_view_get_height"
-  external get_top : [>`mathview] obj -> (int * int) =
+  external get_size : [>`mathview_gmetadom] obj -> int * int =
+    "ml_gtk_math_view_get_size"
+  external get_top : [>`mathview_gmetadom] obj -> (int * int) =
    "ml_gtk_math_view_get_top"
-  external set_top : [>`mathview] obj -> int -> int -> unit =
+  external set_top : [>`mathview_gmetadom] obj -> int -> int -> unit =
    "ml_gtk_math_view_set_top"
-  external set_adjustments : [>`mathview] obj -> Gtk.adjustment obj -> Gtk.adjustment obj -> unit =
+  external set_adjustments : [>`mathview_gmetadom] obj -> Gtk.adjustment obj -> Gtk.adjustment obj -> unit =
    "ml_gtk_math_view_set_adjustments"
-  external get_hadjustment : [>`mathview] obj -> Gtk.adjustment obj =
-   "ml_gtk_math_view_get_hadjustment"
-  external get_vadjustment : [>`mathview] obj -> Gtk.adjustment obj =
-   "ml_gtk_math_view_get_vadjustment"
-  external get_buffer : [>`mathview] obj -> Gdk.pixmap =
+  external get_adjustments : [>`mathview_gmetadom] obj ->
+    Gtk.adjustment obj * Gtk.adjustment obj =
+      "ml_gtk_math_view_get_adjustments"
+  external get_buffer : [>`mathview_gmetadom] obj -> Gdk.pixmap =
    "ml_gtk_math_view_get_buffer"
-  external get_drawing_area : [>`mathview] obj -> Gtk.drawing_area obj =
-   "ml_gtk_math_view_get_drawing_area"
-  external set_font_size : [>`mathview] obj -> int -> unit =
+  external set_font_size : [>`mathview_gmetadom] obj -> int -> unit =
    "ml_gtk_math_view_set_font_size"
-  external get_font_size : [>`mathview] obj -> int =
+  external get_font_size : [>`mathview_gmetadom] obj -> int =
    "ml_gtk_math_view_get_font_size"
-  external set_log_verbosity : [>`mathview] obj -> int -> unit =
+  external set_log_verbosity : [>`mathview_gmetadom] obj -> int -> unit =
    "ml_gtk_math_view_set_log_verbosity"
-  external get_log_verbosity : [>`mathview] obj -> int =
+  external get_log_verbosity : [>`mathview_gmetadom] obj -> int =
    "ml_gtk_math_view_get_log_verbosity"
 end
