@@ -21,4 +21,4 @@
  * For details, send a mail to the author.
  *)
 
-type math_view = [Gtk.event_box|`mathview]
+type math_view = [Gtk.widget|`mathview_gmetadom]
