@@ -23,7 +23,7 @@
 
 #include <assert.h>
 
-#include <gtkmathview.h>
+#include <gtk/gtkmathview_gmetadom.h>
 #include <gtk/gtk.h>
 
 #include <caml/mlvalues.h>
@@ -84,35 +84,89 @@ value Val_Element_ref(GdomeElement* elem)
   return Val_Element(elem);
 }
 
-OML_3 (gtk_math_view_get_element_at, GtkMathView_val, Int_val, Int_val, Val_Element)
+ML_2 (gtk_math_view_structure_changed, GtkMathView_val, Element_val, Unit)
+ML_3 (gtk_math_view_attribute_changed, GtkMathView_val, Element_val, DOMString_val, Unit)
+/* OML_3 (gtk_math_view_get_element_at, GtkMathView_val, Int_val, Int_val, Val_Element) */
 ML_1 (gtk_math_view_freeze, GtkMathView_val, Unit)
 ML_1 (gtk_math_view_thaw, GtkMathView_val, Unit)
 ML_2 (gtk_math_view_load_uri, GtkMathView_val, String_val, Val_bool)
-ML_2 (gtk_math_view_load_doc, GtkMathView_val, Document_val, Val_bool)
+ML_2 (gtk_math_view_load_root, GtkMathView_val, Element_val, Val_bool)
 ML_1 (gtk_math_view_unload, GtkMathView_val, Unit)
 ML_2 (gtk_math_view_select, GtkMathView_val, Element_val, Unit)
 ML_2 (gtk_math_view_unselect, GtkMathView_val, Element_val, Unit)
 ML_2 (gtk_math_view_is_selected, GtkMathView_val, Element_val, Val_bool)
 /*
 ML_2 (gtk_math_view_new,GtkAdjustment_val, GtkAdjustment_val, Val_GtkWidget_sink)
-*/
 ML_1 (gtk_math_view_get_width, GtkMathView_val, Val_int)
 ML_1 (gtk_math_view_get_height, GtkMathView_val, Val_int)
+*/
 ML_3 (gtk_math_view_set_top, GtkMathView_val, Int_val, Int_val, Unit)
 ML_3 (gtk_math_view_set_adjustments, GtkMathView_val, GtkAdjustment_val, GtkAdjustment_val, Unit)
+/*
 ML_1 (gtk_math_view_get_hadjustment, GtkMathView_val, Val_GtkWidget)
 ML_1 (gtk_math_view_get_vadjustment, GtkMathView_val, Val_GtkWidget)
+*/
 ML_1 (gtk_math_view_get_buffer, GtkMathView_val, Val_GdkPixmap)
-ML_1 (gtk_math_view_get_drawing_area, GtkMathView_val, Val_GtkWidget)
 ML_2 (gtk_math_view_set_font_size, GtkMathView_val, Int_val, Unit)
 ML_1 (gtk_math_view_get_font_size, GtkMathView_val, Val_int)
 ML_2 (gtk_math_view_set_log_verbosity, GtkMathView_val, Int_val, Unit)
 ML_1 (gtk_math_view_get_log_verbosity, GtkMathView_val, Val_int)
 
+value ml_gtk_math_view_get_element_at (value arg1, value arg2, value arg3)
+{
+   CAMLparam3(arg1, arg2, arg3);
+   CAMLlocal1 (result);
+   GdomeElement* el;
+   if (gtk_math_view_get_element_at(GtkMathView_val (arg1), Int_val(arg2), Int_val(arg3), &el, NULL, NULL))
+     result = Val_option_ptr(el, Val_Element);
+   else
+     result = Val_unit;
+   CAMLreturn (result);
+}
+
+value ml_gtk_math_view_get_adjustments(value arg1)
+{
+   CAMLparam1(arg1);
+   CAMLlocal1(result);
+   GtkAdjustment* hadj;
+   GtkAdjustment* vadj;
+   gtk_math_view_get_adjustments(GtkMathView_val (arg1), &hadj, &vadj);
+   result = alloc(2, 0);
+   Store_field(result, 0, Val_GtkWidget(hadj));
+   Store_field(result, 1, Val_GtkWidget(vadj));
+   CAMLreturn(result);
+}
+
+value ml_gtk_math_view_get_size (value arg1)
+{
+   CAMLparam1(arg1);
+   CAMLlocal1(result);
+   int width, height;
+   gtk_math_view_get_size(GtkMathView_val (arg1), &width, &height);
+   result = alloc(1, 0);
+   Store_field(result, 0, Val_int(width));
+   Store_field(result, 1, Val_int(height));
+   CAMLreturn (result);
+}
+
+value ml_gtk_math_view_get_bounding_box (value arg1)
+{
+   CAMLparam1(arg1);
+   CAMLlocal1(result);
+   int width, height, depth;
+   GtkMathViewBoundingBox gbox;
+   gtk_math_view_get_bounding_box(GtkMathView_val (arg1), &gbox);
+   result = alloc(3, 0);
+   Store_field(result, 0, Val_int(gbox.width));
+   Store_field(result, 1, Val_int(gbox.height));
+   Store_field(result, 2, Val_int(gbox.depth));
+   CAMLreturn (result);
+}
+
 value ml_gtk_math_view_get_top (value arg1)
 {
    CAMLparam1(arg1);
-   CAMLlocal1 (result);
+   CAMLlocal1(result);
    int x, y;
    gtk_math_view_get_top(GtkMathView_val (arg1), &x, &y);
    result = alloc(2, 0);
@@ -176,3 +230,22 @@ value ml_gtk_math_view_gdome_element_option_of_boxed_option (value arg1)
 
    CAMLreturn(res);
 }
+
+value ml_gtk_math_view_model_event_of_boxed_option (value arg1)
+{
+   CAMLparam1(arg1);
+   GdomeElement* nr;
+   CAMLlocal1 (valnr);
+   CAMLlocal1 (res);
+
+   assert(arg1 != Val_int(0));
+   GtkMathViewModelEvent* event = (GtkMathViewModelEvent*) Field(Field(arg1,0),1);
+   res = alloc(4, 0);
+   Store_field(res, 0, Val_option_ptr(event->id, Val_Element_ref));
+   Store_field(res, 1, Val_int(event->x));
+   Store_field(res, 2, Val_int(event->y));
+   Store_field(res, 3, Val_int(event->state));
+
+   CAMLreturn(res);
+}
+
